# Build with --debug (1) or --symbols (0)
%global debug   0
%global plugindir %{_usr}/lib/%{name}/plugins
%global libplugindir %{_usr}/lib/librnd/plugins

## NOTE This spec must be auto-generated.
# Only edit version, release and svn revision in here.
# See packaging.README for full details.
#
# The current librnd-devel package in the same Mga release system
# as building for and in, must be installed before auto updating
# the spec.
#
# For svn snapshot:
# Run './mk-tar' in SOURCES and note the svn revision # in output.
# In this spec. edit the '#%%global svn' to the new revision and
# replace '#' with percent sign if not already there.
#
# For full release:
# Get the new tarball
# Replace percent sign with '#' in '%%global svn' line
#
# Then for either full or snapshot release:
# Edit this spec to the new Version and Release, save and close.
# Now run './mk-spec sch-rnd' in SOURCES to re-create
# this spec file with any upstream changes.
##############################################

# commented out if not svn snapshot
#%%global svn

Name:           sch-rnd
Version:        1.0.7
Release:        1%{?dist}
Summary:        Standard installation
License:        GPL-2.0-or-later and LGPL-2.0-or-later and BSD-1-Clause and MIT
Group:          Sciences/Other
URL:            http://repo.hu/projects/%{name}
Source0:        %{URL}/releases/%{name}%{?svn:-%{svn}}%{!?svn:-%{version}}.tar.gz
Source1:        mk-tar
Source2:        mk-spec
#Source3:        %%{name}.svg
Source4:        %{name}.desktop
Source5:        %{name}-spec.tpl
Source6:        packaging.README

BuildRequires:  gcc make desktop-file-utils
BuildRequires:  libfungw-devel libgenht-devel
BuildRequires:  librnd-devel >= 4.2.0
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libxml-2.0)

Requires:       %{name}-core = %{version}-%{release}
Requires:       hicolor-icon-theme coreutils
Recommends:     %{name}-io-alien = %{version}-%{release}
Recommends:     %{name}-lib-gui = %{version}-%{release}
Recommends:     %{_lib}rnd4-hid-gtk2-gl >= 4.2.0
Recommends:     %{_lib}rnd4-hid-gtk2-gdk >= 4.2.0
Recommends:     %{name}-export-extra = %{version}-%{release}
Recommends:     %{name}-doc = %{version}-%{release}
Recommends:     %{name}-doc = %{version}-%{release}

%description
sch-rnd is a highly modular schematic capture software with a rich set of
plugins for communicating with various external design tools and other
EDA/CAD packages.

Feature highlights:
  - explicit abstract model
  - back annotation support
  - multiple sheets

File formats and compatibility:
  - text based, tree structured native file format (lihata)
  - import netlist:
    * altium schematics
    * EasyEDA std, multi-page schematics sheets
    * geda cschem schematics (v2)
    * lihata cschem schematics (any version)
    * cschem non-graphical schematic sheets in fawk format
    * cschem non-graphical schematic sheets in tEDAx format

For full details of supported formats etc. please visit:
http://www.repo.hu/projects/sch-rnd/datasheet.html

%package core
Summary:        Executable with the core functionality and boxsym-rnd
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{_lib}rnd4 >= 4.2.0

%description core
Includes the data model, the most common action commands, the native file
format. Can be used in headless mode or batch/scripted mode for automated
processing or with GUI (if sch-rnd-lib-gui and librnd GUI HIDs are installed).

%package doc
Summary:        Documentation
BuildArch:      noarch

%description doc
User manual and developer doc (HTML).

%package debug
Summary:        Debug and diagnostics
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}

%description debug
Extra action commands to help in debugging and diagnosing problems and bugs.

%package export-gd
Summary:        Export formats that require libgd
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}
Requires:       %{_lib}rnd4-pixmap >= 4.2.0

%description export-gd
Bitmap export plugin (png, jpeg, etc.)

%package export-vector
Summary:        Export formats: vector graphics
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}
Requires:       %{_lib}rnd4 >= 4.2.0

%description export-vector
Common vector graphic export formats: ps, eps, svg.

%package export-extra
Summary:        Export formats: special/extra
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}
Requires:       %{name}-export-vector = %{version}-%{release}

%description export-extra
Less commonly used export formats: abstract model text export, direct
printing with lpr.

%package io-alien
Summary:        File format compatibility with other schematics capture tools
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}

%description io-alien
Load and/or save boards in file formats supported by other EDA tools,
geda/gschem, lepton-eda, TinyCAD, Altium.

%package lib-gui
Summary:        Support library for building the GUI
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}
Requires:       %{_lib}rnd4-lib-gui >= 4.2.0

%description lib-gui
Provides sch-rnd specific dialog boxes and top window GUI elements.

%package sim
Summary:        High level circuit simulation
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core = %{version}-%{release}
Requires:       %{name}-lib-gui = %{version}-%{release}

%description sim
Circuit simulation that can export and execute SPICE (ngspice) in the
background and save or present the results. Works both from the GUI (with
dialogs for configuring simulation setups, presenting plots and data in
the same dialog) and from CLI (with actions using existing configuration,
saving output data to a computer readable file).

%prep
%autosetup -n %{name}-%{?svn}%{!?svn:%{version}} -p1

%build
./configure \
--CFLAGS="%{build_cflags} -Wno-incompatible-pointer-types" \
--libarchdir=%{_lib} \
--all=disable --buildin-funcmap --buildin-act_read --buildin-place --buildin-symlib_local --buildin-lib_netlist_exp --buildin-std_tools --buildin-renumber --buildin-io_ngrp_tedax --buildin-backann --buildin-std_cschem --buildin-export_tedax --buildin-lib_tedax --buildin-lib_anymap --buildin-hlibrary_fs --buildin-std_forge --buildin-std_devmap --buildin-propedit --buildin-io_ngrp_fawk --buildin-io_lihata --buildin-target_spice --buildin-target_pcb --buildin-act_draw --buildin-target_none --buildin-symlib_fs --buildin-query --buildin-lib_target --buildin-export_spice --buildin-lib_ngrp --buildin-construct --plugin-lib_alien --plugin-export_ps --plugin-export_bom --plugin-export_abst --plugin-io_orcad --plugin-io_altium --plugin-sim_gui --plugin-sch_dialogs --plugin-lib_plot --plugin-export_lpr --plugin-export_tedax_footprint --plugin-export_svg --plugin-sim --plugin-gui --plugin-diag --plugin-sim_ngspice --plugin-io_easyeda --plugin-io_tinycad --plugin-io_geda --plugin-export_png --plugin-lib_ucdf \
%if %{debug} == 1
        prefix=%{_prefix} --debug
%else
        prefix=%{_prefix} --symbols
%endif

%install
make
%make_install

# Install icon
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
cp doc/resources/logo.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# Install Desktop files
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE4}
%check

%files
# Meta-Package with desktop file
%doc AUTHORS README Release_notes
%license COPYING library/symbol/LICENSE

%files doc
%doc %{_docdir}/%{name}/

%files core
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_usr}/lib/%{name}
%dir %{_usr}/lib/%{name}/plugins
%dir %{_datadir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_bindir}/boxsym-rnd
%{_mandir}/man1/boxsym-rnd.1*
%{_mandir}/man5/boxsym-rnd.5*
%{_usr}/lib/%{name}/boxsym-rnd/
%{_usr}/lib/%{name}/minuid
%config(noreplace) %{_sysconfdir}/%{name}/%{name}-conf.lht
%config(noreplace) %{_sysconfdir}/%{name}/menu-default.lht
%{_datadir}/%{name}/default-sheet.lht
%{_datadir}/%{name}/devmap/
%{_datadir}/%{name}/font/
%{_datadir}/%{name}/symbol/
%{_datadir}/%{name}/spice/
%{_datadir}/%{name}/hlibrary/
%config(noreplace) %{_sysconfdir}/%{name}/funcmap.conf
%config(noreplace) %{_sysconfdir}/%{name}/renumber.conf
%config(noreplace) %{_sysconfdir}/%{name}/std_cschem.conf
%config(noreplace) %{_sysconfdir}/%{name}/std_devmap.conf
%config(noreplace) %{_sysconfdir}/%{name}/target_pcb.conf
%config(noreplace) %{_sysconfdir}/%{name}/target_spice.conf
%doc AUTHORS README Release_notes

%files debug
%{plugindir}/diag.pup
%{plugindir}/diag.so
%doc AUTHORS README Release_notes
  
%files export-gd
%{plugindir}/export_png.pup
%{plugindir}/export_png.so
%doc AUTHORS README Release_notes

%files export-vector
%{plugindir}/export_ps.pup
%{plugindir}/export_ps.so
%{plugindir}/export_svg.pup
%{plugindir}/export_svg.so
%{plugindir}/export_tedax_footprint.pup
%{plugindir}/export_tedax_footprint.so
%doc AUTHORS README Release_notes

%files export-extra
%{plugindir}/export_abst.pup
%{plugindir}/export_abst.so
%{plugindir}/export_bom.pup
%{plugindir}/export_bom.so
%{plugindir}/export_lpr.pup
%{plugindir}/export_lpr.so
%config(noreplace) %{_sysconfdir}/%{name}/export_bom.conf
%doc AUTHORS README Release_notes

%files io-alien
%{plugindir}/io_altium.pup
%{plugindir}/io_altium.so
%{plugindir}/io_easyeda.pup
%{plugindir}/io_easyeda.so
%{plugindir}/io_geda.pup
%{plugindir}/io_geda.so
%{plugindir}/io_orcad.pup
%{plugindir}/io_orcad.so
%{plugindir}/io_tinycad.pup
%{plugindir}/io_tinycad.so
%{plugindir}/lib_alien.pup
%{plugindir}/lib_alien.so
%{plugindir}/lib_ucdf.pup
%{plugindir}/lib_ucdf.so
%config(noreplace) %{_sysconfdir}/%{name}/io_altium.conf
%config(noreplace) %{_sysconfdir}/%{name}/io_easyeda.conf
%config(noreplace) %{_sysconfdir}/%{name}/io_geda.conf
%config(noreplace) %{_sysconfdir}/%{name}/io_orcad.conf
%config(noreplace) %{_sysconfdir}/%{name}/io_tinycad.conf
%doc AUTHORS README Release_notes

%files lib-gui
%{plugindir}/gui.pup
%{plugindir}/gui.so
%{plugindir}/lib_plot.pup
%{plugindir}/lib_plot.so
%{plugindir}/sch_dialogs.pup
%{plugindir}/sch_dialogs.so
%config(noreplace) %{_sysconfdir}/%{name}/adialogs.conf
%doc AUTHORS README Release_notes

%files sim
%{plugindir}/sim_gui.pup
%{plugindir}/sim_gui.so
%{plugindir}/sim_ngspice.pup
%{plugindir}/sim_ngspice.so
%{plugindir}/sim.pup
%{plugindir}/sim.so
%config(noreplace) %{_sysconfdir}/%{name}/sim_gui.conf
%config(noreplace) %{_sysconfdir}/%{name}/sim.conf
%doc AUTHORS README Release_notes

%changelog
* Sat Feb 1 2025 Pappy Packager <skrochen@krotek.com> - 1.0.7-1
- Rebuilt for Fedora 41
